==> canada_post-0.0.5.tar.gz: lib/src/models/mailing_scenario/service.dart <==
import 'package:meta/meta.dart';
import 'package:xml/xml.dart';

class Service {

  /// DOM.RP 	Regular Parcel |
  /// DOM.EP 	Expedited Parcel |
  /// DOM.XP 	Xpresspost |
  /// DOM.XP.CERT 	Xpresspost Certified |
  /// DOM.PC 	Priority |
  /// DOM.LIB 	Library Materials |
  /// USA.EP 	Expedited Parcel USA |
  /// USA.PW.ENV 	Priority Worldwide Envelope USA |
  /// USA.PW.PAK 	Priority Worldwide pak USA |
  /// USA.PW.PARCEL 	Priority Worldwide Parcel USA |
  /// USA.SP.AIR 	Small Packet USA Air |
  /// USA.TP 	Tracked Packet – USA |
  /// USA.TP.LVM 	Tracked Packet – USA (LVM) |
  /// (large volume mailers) |
  /// USA.XP 	Xpresspost USA |
  /// INT.XP 	Xpresspost International |
  /// INT.IP.AIR 	International Parcel Air |
  /// INT.IP.SURF 	International Parcel Surface |
  /// INT.PW.ENV 	Priority Worldwide Envelope Int’l |
  /// INT.PW.PAK 	Priority Worldwide pak Int’l |
  /// INT.PW.PARCEL 	Priority Worldwide parcel Int’l |
  /// INT.SP.AIR 	Small Packet International Air |
  /// INT.SP.SURF 	Small Packet International Surface |
  /// INT.TP
  String serviceCode;

  Service({
    @required this.serviceCode
  });
}

void buildServices(XmlBuilder builder, List<Service> services) {
  if (services == null) return;
  if (services.length > 20) {
    throw ArgumentError('limit of 20 services per request');
  }
  else if (services.length > 0) {
    builder.element('services', nest: () {
      services.forEach((service) {
        builder.element('service', nest: service.serviceCode);
      });
    });
  }
}

==> canada_post-0.0.9.tar.gz: lib/src/models/mailing_scenario/service.dart <==
import 'package:meta/meta.dart';
import 'package:xml/xml.dart';

class Service {

  /// DOM.RP 	Regular Parcel |
  /// DOM.EP 	Expedited Parcel |
  /// DOM.XP 	Xpresspost |
  /// DOM.XP.CERT 	Xpresspost Certified |
  /// DOM.PC 	Priority |
  /// DOM.LIB 	Library Materials |
  /// USA.EP 	Expedited Parcel USA |
  /// USA.PW.ENV 	Priority Worldwide Envelope USA |
  /// USA.PW.PAK 	Priority Worldwide pak USA |
  /// USA.PW.PARCEL 	Priority Worldwide Parcel USA |
  /// USA.SP.AIR 	Small Packet USA Air |
  /// USA.TP 	Tracked Packet – USA |
  /// USA.TP.LVM 	Tracked Packet – USA (LVM) |
  /// (large volume mailers) |
  /// USA.XP 	Xpresspost USA |
  /// INT.XP 	Xpresspost International |
  /// INT.IP.AIR 	International Parcel Air |
  /// INT.IP.SURF 	International Parcel Surface |
  /// INT.PW.ENV 	Priority Worldwide Envelope Int’l |
  /// INT.PW.PAK 	Priority Worldwide pak Int’l |
  /// INT.PW.PARCEL 	Priority Worldwide parcel Int’l |
  /// INT.SP.AIR 	Small Packet International Air |
  /// INT.SP.SURF 	Small Packet International Surface |
  /// INT.TP
  String serviceCode;

  Service({
    @required this.serviceCode
  });
}

void buildServices(XmlBuilder builder, List<Service> services) {
  if (services != null && services.length > 20) {
    throw ArgumentError('limit of 20 services per request');
  }
  else if (services != null && services.length > 0) {
    builder.element('services', nest: () {
      services.forEach((service) {
        builder.element('service-code', nest: service.serviceCode);
      });
    });
  }
}
